@@ -140,6 +140,47 @@ async def test_get_event(
         start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
         end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
         transparency="transparent",
+        private_calendar_id="some-calendar-id",
+    )
+
+
+async def test_get_event_as_resource_calendar_all_day_event(
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
+    url_request: Callable[[], str],
+) -> None:
+    """Test getting a calendar event for a resource."""
+
+    json_response(
+        {
+            "id": "some-event-id-1",
+            "summary": "Event 1",
+            "description": "Event description 1",
+            "start": {
+                # All day event incorrectly set as dateTime
+                "dateTime": "2022-04-13T00:00:00+02:00",
+                "timeZone": "Europe/Oslo",
+            },
+            "end": {"dateTime": "2022-04-14T00:00:00+02:00", "timeZone": "Europe/Oslo"},
+            "status": "confirmed",
+            "transparency": "transparent",
+        }
+    )
+    calendar_service = await calendar_service_cb()
+    event = await calendar_service.async_get_event(
+        "some-calendar-id@resource.calendar.google.com", "some-event-id-1"
+    )
+    assert url_request() == [
+        "/calendars/some-calendar-id@resource.calendar.google.com/events/some-event-id-1"
+    ]
+    assert event == Event(
+        id="some-event-id-1",
+        summary="Event 1",
+        description="Event description 1",
+        start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
+        end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
+        transparency="transparent",
+        private_calendar_id="some-calendar-id@resource.calendar.google.com",
     )
 
 
@@ -188,7 +229,7 @@ async def test_list_events(
     )
     assert url_request() == [
         f"/calendars/some-calendar-id/events?{EVENT_LIST_PARAMS}"
-        "&timeMin=2022-04-30T01:31:02%2B00:00"
+        "&timeMin=2022-04-30T01:31:02Z"
     ]
     assert result.items == [
         Event(
@@ -198,6 +239,7 @@ async def test_list_events(
             start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
             end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
             transparency="transparent",
+            private_calendar_id="some-calendar-id",
         ),
         Event(
             id="some-event-id-2",
@@ -206,6 +248,7 @@ async def test_list_events(
             start=DateOrDatetime(date=datetime.date(2022, 4, 14)),
             end=DateOrDatetime(date=datetime.date(2022, 4, 20)),
             transparency="opaque",
+            private_calendar_id="some-calendar-id",
         ),
     ]
     assert result.page_token is None
@@ -243,6 +286,86 @@ async def test_list_events_with_date_limit(
     ]
 
 
+@freeze_time("2022-04-30 07:31:02", tz_offset=-6)
+async def test_list_events_with_all_day_event_in_resource_calendar(
+    calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
+    json_response: ApiResult,
+    url_request: Callable[[], str],
+) -> None:
+    """Test list calendars API."""
+
+    json_response(
+        {
+            "items": [
+                {
+                    "id": "some-event-id-1",
+                    "summary": "Event 1",
+                    "description": "Event description 1",
+                    "start": {
+                        "dateTime": "2022-04-13T00:00:00+02:00",
+                        "timeZone": "Europe/Oslo",
+                    },
+                    "end": {
+                        "dateTime": "2022-04-14T00:00:00+02:00",
+                        "timeZone": "Europe/Oslo",
+                    },
+                    "status": "confirmed",
+                    "transparency": "transparent",
+                },
+                {
+                    "id": "some-event-id-2",
+                    "summary": "Event 2",
+                    "description": "Event description 2",
+                    "start": {
+                        "dateTime": "2022-04-14T00:00:00+02:00",
+                        "timeZone": "Europe/Oslo",
+                    },
+                    "end": {
+                        "dateTime": "2022-04-20T00:00:00+02:00",
+                        "timeZone": "Europe/Oslo",
+                    },
+                    "transparency": "opaque",
+                },
+            ]
+        }
+    )
+    calendar_service = await calendar_service_cb()
+    result = await calendar_service.async_list_events(
+        ListEventsRequest(calendar_id="some-calendar-id@resource.calendar.google.com")
+    )
+    assert url_request() == [
+        f"/calendars/some-calendar-id@resource.calendar.google.com/events?{EVENT_LIST_PARAMS}"
+        "&timeMin=2022-04-30T01:31:02Z"
+    ]
+    assert result.items == [
+        Event(
+            id="some-event-id-1",
+            summary="Event 1",
+            description="Event description 1",
+            start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
+            end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
+            transparency="transparent",
+            private_calendar_id="some-calendar-id@resource.calendar.google.com",
+        ),
+        Event(
+            id="some-event-id-2",
+            summary="Event 2",
+            description="Event description 2",
+            start=DateOrDatetime(date=datetime.date(2022, 4, 14)),
+            end=DateOrDatetime(date=datetime.date(2022, 4, 20)),
+            transparency="opaque",
+            private_calendar_id="some-calendar-id@resource.calendar.google.com",
+        ),
+    ]
+    assert result.page_token is None
+    assert result.sync_token is None
+
+    items = []
+    async for result_page in result:
+        items.extend(result_page.items)
+    assert len(items) == 2
+
+
 async def test_create_event_with_date(
     calendar_service_cb: Callable[[], Awaitable[GoogleCalendarService]],
     json_request: ApiRequest,
@@ -372,6 +495,7 @@ async def test_event_missing_summary(
             start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
             end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
             transparency="transparent",
+            private_calendar_id="some-calendar-id",
         )
     ]
 
@@ -478,13 +602,13 @@ async def test_list_events_multiple_pages_with_iterator(
     assert url_request() == [
         # Request #1
         f"/calendars/some-calendar-id/events?{EVENT_LIST_PARAMS}"
-        "&timeMin=2022-04-30T01:31:02%2B00:00",
+        "&timeMin=2022-04-30T01:31:02Z",
         # Request #2
         f"/calendars/some-calendar-id/events?{EVENT_LIST_PARAMS}"
-        "&pageToken=page-token-1&timeMin=2022-04-30T01:31:02%2B00:00",
+        "&pageToken=page-token-1&timeMin=2022-04-30T01:31:02Z",
         # Request #3
         f"/calendars/some-calendar-id/events?{EVENT_LIST_PARAMS}"
-        "&pageToken=page-token-2&timeMin=2022-04-30T01:31:02%2B00:00",
+        "&pageToken=page-token-2&timeMin=2022-04-30T01:31:02Z",
     ]
     assert items == [
         Event(
@@ -494,6 +618,7 @@ async def test_list_events_multiple_pages_with_iterator(
             start=DateOrDatetime(date=datetime.date(2022, 4, 13)),
             end=DateOrDatetime(date=datetime.date(2022, 4, 14)),
             transparency="transparent",
+            private_calendar_id="some-calendar-id",
         ),
         Event(
             id="some-event-id-2",
@@ -502,6 +627,7 @@ async def test_list_events_multiple_pages_with_iterator(
             start=DateOrDatetime(date=datetime.date(2022, 4, 14)),
             end=DateOrDatetime(date=datetime.date(2022, 4, 20)),
             transparency="opaque",
+            private_calendar_id="some-calendar-id",
         ),
     ]
     assert page_tokens == ["page-token-1", "page-token-2", None]
@@ -524,7 +650,7 @@ async def test_list_event_url_encoding(
     )
     assert url_request() == [
         f"/calendars/en.usa#holiday@group.v.calendar.google.com/events?{EVENT_LIST_PARAMS}"
-        "&timeMin=2022-04-30T01:31:02%2B00:00"
+        "&timeMin=2022-04-30T01:31:02Z"
     ]
 
 
